package wtalk;

/*
 * Copyright (C) 2002 Matthew Wronka <wronkm@rpi.edu>
 * This file is released under the GNU General Public License version 2,
 * a version of which should have been provided along with this file.
 *
 * You might also find a copy at:
 * http://dmc.sf.net/files/gpl.txt
 * http://www.fsf.org/copyleft/gpl.html
 */

import wtalk.protocols.*;

/**
 * Controls the creation of WTalkProtocol objects, which are the foundation for
 *	all communications in WTalk.
 * <p>
 * Several constants are defined here which represent each of the supported
 * 	protocols.  Two special constants, <em>UNDEF</em> and <em>MAX</em>
 *	are provided as well.
 *
 * @author Matthew Wronka <wronkm@rpi.edu>
 * @version 3.0
 */

public class Protocol {
	public static final int UNDEF = 0;
	public static final int DMC = 1;	// DMC protocol
	public static final int USA = 2;	// Secure Multi-Party Chat Env
	public static final int PMS = 3;	// IIMS
	public static final int POP = 4;	// POP3 and SMTP
	public static final int IRC = 5;	// Internet Relay Chat (RFC1459)
	public static final int LILY = 6;	// http://lilycore.sf.net/
	public static final int JABBER = 7;	// http://www.jabber.org/
	public static final int MAX = 8;


	/**
	 * Returns a WTalkProtocol according to the 
	 *	paramater <code>protocol</code>.
	 *
	 * @param name Name to be used by this protocol.
	 * @param protocol One of the defined constants
	 * 	 representing a supported protocol.
	 * @return Returns a WTalkProtocol if <code>protocol</code> is supported, otherwise null.
	 */
	public static WTalkProtocol getProtocol(String name, int protocol) {
		switch(protocol) {
		case USA:	return new wtalk.protocols.usa.Usa();
		case PMS:	return new wtalk.protocols.pms.PMSProtocol(name);
		case POP:	return new wtalk.protocols.pop.POP3SMTP();
		case IRC:	return new wtalk.protocols.irc.IRC();
		//case LILY:	return new wtalk.protocols.
		//case JABBER:	return new wtalk.protocols.
		default:
			System.err.println("Protocol " + protocol + " unknown.");
		}

		return null;
	} 

	public static int getProtocolByName(String s) {
		if( s.equalsIgnoreCase("usa") ) {
			return USA;
		} else if( s.equalsIgnoreCase("pms")){
			return PMS;
		} else if( s.equalsIgnoreCase("pop")){
			return POP;
		} else if( s.equalsIgnoreCase("dmc")){
			return DMC;
		} else if( s.equalsIgnoreCase("irc")){
			return IRC;
		} else if( s.equalsIgnoreCase("lily")){
			return LILY;
		} else if( s.equalsIgnoreCase("jabber")){
			return JABBER;
		}

		return UNDEF; 
	}
}
